@@ -1,24 +1,25 @@
 from rest_framework import generics
 from rest_framework.filters import DjangoFilterBackend
+from rest_framework_gis.filters import *
+from rest_framework_gis.pagination import GeoJsonPagination
 
 from .models import *
 from .serializers import *
-from rest_framework_gis.filters import *
 
 
 class LocationList(generics.ListCreateAPIView):
     model = Location
     serializer_class = LocationGeoSerializer
-    pagination_serializer_class = PaginatedLocationGeoSerializer
-    paginate_by_param = 'limit'
-    paginate_by = 40
-    
+    queryset = Location.objects.all()
+    pagination_class = PaginatedLocationGeoSerializer
+
 location_list = LocationList.as_view()
-    
-    
+
+
 class LocationDetails(generics.RetrieveUpdateDestroyAPIView):
     model = Location
     serializer_class = LocationGeoSerializer
+    queryset = Location.objects.all()
 
 location_details = LocationDetails.as_view()
 
@@ -26,10 +27,9 @@ location_details = LocationDetails.as_view()
 class GeojsonLocationList(generics.ListCreateAPIView):
     model = Location
     serializer_class = LocationGeoFeatureSerializer
-    pagination_serializer_class = PaginatedLocationGeoFeatureSerializer
-    paginate_by_param = 'limit'
-    paginate_by = 40
-    
+    queryset = Location.objects.all()
+    pagination_class = GeoJsonPagination
+
 geojson_location_list = GeojsonLocationList.as_view()
 
 
@@ -85,23 +85,50 @@ geojson_location_within_degrees_of_point_list = GeojsonLocationWithinDegreesOfPo
 class GeojsonLocationDetails(generics.RetrieveUpdateDestroyAPIView):
     model = Location
     serializer_class = LocationGeoFeatureSerializer
+    queryset = Location.objects.all()
 
 geojson_location_details = GeojsonLocationDetails.as_view()
 
 
+class GeojsonLocationDetailsHidden(generics.RetrieveUpdateDestroyAPIView):
+    model = Location
+    serializer_class = LocationGeoFeatureMethodSerializer
+    queryset = Location.objects.all()
+
+geojson_location_details_hidden = GeojsonLocationDetailsHidden.as_view()
+
+
+class GeojsonLocationDetailsNone(generics.RetrieveUpdateDestroyAPIView):
+    model = Location
+    serializer_class = NoneGeoFeatureMethodSerializer
+    queryset = Location.objects.all()
+
+geojson_location_details_none = GeojsonLocationDetailsNone.as_view()
+
+
 class GeojsonLocationSlugDetails(generics.RetrieveUpdateDestroyAPIView):
     model = Location
     lookup_field = 'slug'
     serializer_class = LocationGeoFeatureSlugSerializer
+    queryset = Location.objects.all()
 
 geojson_location_slug_details = GeojsonLocationSlugDetails.as_view()
 
 
-class GeojsonLocationFalseIDDetails(generics.RetrieveUpdateDestroyAPIView):
+class GeojsonLocationFalseIdDetails(generics.RetrieveUpdateDestroyAPIView):
     model = Location
-    serializer_class = LocationGeoFeatureFalseIDSerializer
+    serializer_class = LocationGeoFeatureFalseIdSerializer
+    queryset = Location.objects.all()
 
-geojson_location_falseid_details = GeojsonLocationFalseIDDetails.as_view()
+geojson_location_falseid_details = GeojsonLocationFalseIdDetails.as_view()
+
+
+class GeojsonLocationNoIdDetails(generics.RetrieveUpdateDestroyAPIView):
+    model = Location
+    serializer_class = LocationGeoFeatureNoIdSerializer
+    queryset = Location.objects.all()
+
+geojson_location_noid_details = GeojsonLocationNoIdDetails.as_view()
 
 
 class LocationFilter(GeoFilterSet):
@@ -110,7 +137,6 @@ class LocationFilter(GeoFilterSet):
     class Meta:
         model = Location
 
-
 class GeojsonLocationContainedInGeometry(generics.ListAPIView):
     queryset = Location.objects.all()
     serializer_class = LocationGeoSerializer
@@ -119,3 +145,35 @@ class GeojsonLocationContainedInGeometry(generics.ListAPIView):
     filter_backends = (DjangoFilterBackend,)
 
 geojson_contained_in_geometry = GeojsonLocationContainedInGeometry.as_view()
+
+
+class GeojsonLocatedFileDetails(generics.RetrieveUpdateDestroyAPIView):
+    model = LocatedFile
+    serializer_class = LocatedFileGeoFeatureSerializer
+    queryset = LocatedFile.objects.all()
+
+geojson_located_file_details = GeojsonLocatedFileDetails.as_view()
+
+
+class GeojsonBoxedLocationDetails(generics.RetrieveUpdateDestroyAPIView):
+    model = BoxedLocation
+    serializer_class = BoxedLocationGeoFeatureSerializer
+    queryset = BoxedLocation.objects.all()
+
+geojson_boxedlocation_details = GeojsonBoxedLocationDetails.as_view()
+
+
+class GeojsonBoxedLocationList(generics.ListCreateAPIView):
+    model = BoxedLocation
+    serializer_class = BoxedLocationGeoFeatureSerializer
+    queryset = BoxedLocation.objects.all()
+
+geojson_boxedlocation_list = GeojsonBoxedLocationList.as_view()
+
+
+class GeojsonLocationBboxList(generics.ListCreateAPIView):
+    model = Location
+    serializer_class = LocationGeoFeatureBboxSerializer
+    queryset = Location.objects.all()
+
+geojson_location_bbox_list = GeojsonLocationBboxList.as_view()
