@@ -1,4 +1,7 @@
 from settings import *
+# RENAME THIS FILE local_settings.py IF YOU NEED TO CUSTOMIZE SOME SETTINGS
+# BUT DO NOT COMMIT
+TEST_PERFORMANCE = False
 
 DATABASES = {
     'default': {
@@ -18,18 +21,30 @@ INSTALLED_APPS = (
     'django.contrib.messages',
     'django.contrib.staticfiles',
     'django.contrib.gis',
-    
+
     # geodjango widgets
     #'olwidget',
-    
+
     # admin
     #'grappelli',
     'django.contrib.admin',
-    
+
     # rest framework
     'rest_framework',
     'rest_framework_gis',
-    
+
     # test app
-    'django_restframework_gis_tests'
-)
\ No newline at end of file
+    'django_restframework_gis_tests',
+    'django_extensions'
+)
+
+POSTGIS_VERSION = (2, 1)
+
+#REST_FRAMEWORK = {
+#     'DEFAULT_RENDERER_CLASSES': (
+#         'drf_ujson.renderers.UJSONRenderer',
+#     ),
+#     'DEFAULT_PARSER_CLASSES': (
+#        'drf_ujson.parsers.UJSONParser',
+#     ),
+#}
